﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2013 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System;
using System.Diagnostics;
using System.Linq;
using HeuristicLab.Analysis.AlgorithmBehavior.Analyzers;
using Microsoft.VisualStudio.TestTools.UnitTesting;

namespace AlgorithmBehaviorUnitTests {
  [TestClass]
  public class TestVolumeCalculation {
    [TestMethod]
    public void TestVolCalc() {
      int dim = 4;
      int size = 20;
      var data = CreateRandomData(size, dim);
      var dataList = data.ToList();
      Stopwatch watch = new Stopwatch();


      //calculate convex hull
      watch.Start();
      var convexHull = LPHull.Calculate(data);
      watch.Stop();
      Console.WriteLine("Convex hull calculation took : " + watch.Elapsed.TotalSeconds + " seconds.");


      //calculate volume of convex hull
      watch.Start();
      double volume = ConvexHullMeasures.CalculateVolumeNew(convexHull);
      watch.Stop();
      Console.WriteLine("Volume calculation of convex hull took : " + watch.Elapsed.TotalSeconds + " seconds.");
      Console.WriteLine("Volume of convex hull is: " + volume);


      //do volume calculation from the whole data set
      watch.Start();
      volume = ConvexHullMeasures.CalculateVolumeNew(dataList);
      watch.Stop();
      Console.WriteLine("Volume calculation of whole data set took : " + watch.Elapsed.TotalSeconds + " seconds.");
      Console.WriteLine("Volume of whole data is: " + volume);
    }


    private double[][] CreateRandomData(int n, int m) {
      double[][] result = new double[n][];
      Random rand = new Random();

      for (int i = 0; i < n; i++) {
        result[i] = new double[m];
        for (int j = 0; j < m; j++) {
          result[i][j] = (double)rand.Next(1, 60);
        }
      }
      return result;
    }
  }
}
